﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.IO;
using System.Windows.Forms;
using PluginInterfaceLibrary;

namespace Manager
{
    public partial class PluginManagerForm : Form
    {
        PluginManager pluginManager;

        public PluginManagerForm(PluginManager pluginManager)
        {
            InitializeComponent();

            this.pluginManager = pluginManager;

            pluginGrid.Rows.Clear();

            if (this.pluginManager.totalPluginCount > 0)
            {
                for (int i = 0; i < this.pluginManager.importPluginCount; i++)
                {
                    IPlugin plugin = this.pluginManager.getPlugin(i, PluginManager.PluginType.ptImport);
                    pluginGrid.Rows.Add(Path.GetFileName(pluginManager.getPath(i, PluginManager.PluginType.ptImport)),
                        plugin.name, "Import", plugin.vendor, plugin.version, null);
                }

                for (int i = 0; i < this.pluginManager.processingPluginCount; i++)
                {
                    IPlugin plugin = this.pluginManager.getPlugin(i, PluginManager.PluginType.ptProcessing);
                    pluginGrid.Rows.Add(Path.GetFileName(pluginManager.getPath(i, PluginManager.PluginType.ptProcessing)), 
                        plugin.name, "Processing", plugin.vendor, plugin.version, null);
                }

                for (int i = 0; i < this.pluginManager.exportPluginCount; i++)
                {
                    IPlugin plugin = this.pluginManager.getPlugin(i, PluginManager.PluginType.ptExport);
                    pluginGrid.Rows.Add(Path.GetFileName(pluginManager.getPath(i, PluginManager.PluginType.ptExport)), 
                        plugin.name, "Export", plugin.vendor, plugin.version, null);
                }
            }
        }

        public void setFolderPath(string path)
        {
            folderTextBox.Text = path;
            folderDialog.SelectedPath = path;
        }

        public string getFolderPath()
        {
            return folderTextBox.Text;
        }

        private void pluginGrid_Click(object sender, EventArgs e)
        {
            if (pluginGrid.CurrentCell != null && 
                pluginGrid.CurrentCell.ColumnIndex == configCol.Index && pluginGrid.CurrentCell.RowIndex != -1)
            {
                pluginManager.getPlugin(pluginGrid.CurrentCell.RowIndex).configure();
                // this causes problems (null reference exception) in linux
                // pluginGrid.CurrentCell = null;
            }
        }

        private void pluginGrid_SelectionChanged(object sender, EventArgs e)
        {
            if (pluginGrid.CurrentCell != null && pluginGrid.CurrentCell.RowIndex != -1)
                descriptionTextBox.Text = pluginManager.getPlugin(pluginGrid.CurrentCell.RowIndex).description;
            else
                descriptionTextBox.Text = "";
        }

        private void folderButton_Click(object sender, EventArgs e)
        {
            folderDialog.SelectedPath = folderTextBox.Text;
            if (folderDialog.ShowDialog() == DialogResult.OK)
                folderTextBox.Text = folderDialog.SelectedPath;
        }
    }
}
