﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InternalData;

namespace Manager
{
    public partial class ProgramSettingsForm : Form
    {
        private Configuration configuration;

        public ProgramSettingsForm()
        {
            InitializeComponent();
        }

        public void refreshProgramSettings(int startTab, Configuration configuration)
        {
            this.configuration = configuration;

            if (configuration != null)
            {
                lineWidthEdit.Value = configuration.renderingLineWidth;
                vectorsSplitScreenCheckBox.Checked = configuration.vectorsInSplitScreen;
                includeFilesByDefaultCheckbox.Checked = configuration.includeSourceFilesByDefault;
                askBeforeCancelCheckBox.Checked = configuration.askBeforeCancellingProcessing;
                askBeforeClosingCheckBox.Checked = configuration.askBeforeClosingModified;

                switch (configuration.detectionMode)
                {
                    case DetectionMode.dmAutomaticMotion:
                        analysisStartComboBox.SelectedIndex = 0;
                        break;
                    case DetectionMode.dmAutomaticCorner:
                        analysisStartComboBox.SelectedIndex = 1;
                        break;
                    case DetectionMode.dmManual:
                        analysisStartComboBox.SelectedIndex = 2;
                        break;
                }

                switch (configuration.trackingMode)
                {
                    case TrackingMode.tmAutomaticMotion:
                        analysisTrackingComboBox.SelectedIndex = 0;
                        break;
                    case TrackingMode.tmAutomaticCorner:
                        analysisTrackingComboBox.SelectedIndex = 1;
                        break;
                    case TrackingMode.tmFollowing:
                        analysisTrackingComboBox.SelectedIndex = 2;
                        break;
                    case TrackingMode.tmStart:
                        analysisTrackingComboBox.SelectedIndex = 3;
                        break;
                }

                detectionSensitivityTrackBar.Value = configuration.DetectionSensitivity;
                maxVectorsTrackBar.Value = configuration.maxVectors;
            }

            if (startTab >= 0 && startTab < tabControl.TabCount)
                tabControl.SelectedIndex = startTab;
        }

        private void writeProgramSettings(Configuration configuration)
        {
            if (configuration == null)
                configuration = new Configuration();

            if (configuration != null)
            {
                configuration.renderingLineWidth = Convert.ToInt32(lineWidthEdit.Value);
                configuration.vectorsInSplitScreen = vectorsSplitScreenCheckBox.Checked;
                configuration.includeSourceFilesByDefault = includeFilesByDefaultCheckbox.Checked;
                configuration.askBeforeClosingModified = askBeforeClosingCheckBox.Checked;
                configuration.askBeforeCancellingProcessing = askBeforeCancelCheckBox.Checked;

                switch (analysisStartComboBox.SelectedIndex)
                {
                    case 0:
                        configuration.detectionMode = DetectionMode.dmAutomaticMotion;
                        break;
                    case 1:
                        configuration.detectionMode = DetectionMode.dmAutomaticCorner;
                        break;
                    case 2:
                        configuration.detectionMode = DetectionMode.dmManual;
                        break;
                }

                switch (analysisTrackingComboBox.SelectedIndex)
                {
                    case 0:
                        configuration.trackingMode = TrackingMode.tmAutomaticMotion;
                        break;
                    case 1:
                        configuration.trackingMode = TrackingMode.tmAutomaticCorner;
                        break;
                    case 2:
                        configuration.trackingMode = TrackingMode.tmFollowing;
                        break;
                    case 3:
                        configuration.trackingMode = TrackingMode.tmStart;
                        break;
                }

                configuration.DetectionSensitivity = detectionSensitivityTrackBar.Value;
                configuration.maxVectors = maxVectorsTrackBar.Value;
            }
        }

        private void okButton_Click(object sender, EventArgs e)
        {
            writeProgramSettings(configuration);
        }

        private void detectionSensitivityTrackBar_ValueChanged(object sender, EventArgs e)
        {
            switch (detectionSensitivityTrackBar.Value)
            {
                case 1:
                    sensitivityLabel.Text = "Sensitivity: low";
                    break;
                case 2:
                    sensitivityLabel.Text = "Sensitivity: moderate";
                    break;
                case 3:
                    sensitivityLabel.Text = "Sensitivity: high";
                    break;
            }
        }

        private void maxVectorsTrackBar_ValueChanged(object sender, EventArgs e)
        {
            maxVectorsLabel.Text = "Max. vectors: " + (maxVectorsTrackBar.Value * maxVectorsTrackBar.Value).ToString();
        }
    }
}
