﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using PluginInterfaceLibrary;

namespace Manager
{
    public partial class ProjectManagerForm : Form
    {
        private Project project;
        private const int THUMB_SIZE = 100;

        public ProjectManagerForm()
        {
            InitializeComponent();
        }

        public void refreshProjectInfo(Project project, ProjectManager.ProjectFileType fileType,
            string location, IImportPlugin importPlugin)
        {
            this.project = project;
            projNameTextbox.Text = project.name;
            projUserTextbox.Text = project.user;
            projDescriptionTextbox.Text = project.description;
            projDateLabel.Text = "Creation date: " + project.creationDate.ToString();
            projLocationLabel.Text = "Location: " + location;
            includeFilesCheckbox.Checked = project.includeSourceFiles;
            
            string projFileType = "[unknown]";
            if (location != "")
            {
                if (fileType == ProjectManager.ProjectFileType.pftArchive)
                    projFileType = "Compressed archive (" + ProjectManager.PROJ_ARCHIVE_EXT + ")";
                else
                    projFileType = "Single files (" + ProjectManager.PROJ_XML_EXT + ")";
            }

            projFileTypeLabel.Text = "Saved as: " + projFileType;

            filesDataGrid.Rows.Clear();
            filesDataGrid.RowTemplate.Height = THUMB_SIZE;
            filesDataGrid.Columns[2].MinimumWidth = THUMB_SIZE;
            filesDataGrid.Columns[2].Width = THUMB_SIZE;

            Renderer renderer = new Renderer();

            int totalFrames = 0;
            if (importPlugin != null && importPlugin.importedFiles.Length > 0)
                for (int i = 0; i < importPlugin.importedFiles.Length; i++)
                {
                    int startFrame = 0;
                    int endFrame = 0;

                    startFrame = totalFrames + 1;
                    endFrame = startFrame + (importPlugin.importedFiles[i] as IImportedFile).frameCount - 1;

                    Bitmap buffer = new Bitmap(THUMB_SIZE, THUMB_SIZE);
                    Graphics bufferGraphics = Graphics.FromImage(buffer);
                    bufferGraphics.Clip = new Region(new Rectangle(0, 0, THUMB_SIZE, THUMB_SIZE));
                    bufferGraphics.Clear(Color.Black);
                    GraphicsUnit gUnit = GraphicsUnit.Display;
                    renderer.render(bufferGraphics, buffer.GetBounds(ref gUnit), importPlugin, totalFrames, 
                        null, new Point(-1, -1), false, false, false);

                    filesDataGrid.Rows.Add(startFrame.ToString() + "-" + endFrame.ToString(),
                        (importPlugin.importedFiles[i] as IImportedFile).srcFile, buffer);

                    totalFrames += (importPlugin.importedFiles[i] as IImportedFile).frameCount;
                }
        }

        private void writeProjectInfo(Project project)
        {
            project.name = projNameTextbox.Text;
            project.user = projUserTextbox.Text;
            project.description = projDescriptionTextbox.Text;
            project.includeSourceFiles = includeFilesCheckbox.Checked;
        }

        private void cancelButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void okButton_Click(object sender, EventArgs e)
        {
            writeProjectInfo(project);
            Close();
        }

      
    }
}
