﻿/*
multiDAC Export Plugin Interface
Copyright (C) 2009 Felix Schmitt

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

using System;
using System.Collections.Generic;
using System.Drawing;
using System.Text;
using InternalData;

namespace PluginInterfaceLibrary
{
    /** 
     * callback method for retrieving a certain frame 
     * \param frame the frame to retrieve
     * \return the frame as a Bitmap or null
     */
    public delegate Bitmap GetFrameCallback(int frame);

    /**
     * callback method for rendering views created by the plugin back to
     * the main program. it's the program's responsibility to provide
     * a rendering region.
     * \param view the created view as a Bitmap object
     * \return ERR_NOERR on success
     */
    public delegate int RenderViewCallback(Bitmap view);

    /**
     * \interface IExportPlugin
     * Describes the basic interface to an export plugin
     * used for exporting and analyzing result data
     */
    public interface IExportPlugin : IPlugin
    {
        int exportData(object[] runs, int frameCount, GetFrameCallback getFrameCallback,
            RenderViewCallback renderViewCallback);
    }
}
