﻿/*
multiDAC Import Plugin Interface
Copyright (C) 2009 Felix Schmitt

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;
using InternalData;

namespace PluginInterfaceLibrary
{
    /**
     * \interface IFrameRenderer
     * rendering methods for a single Frame object
     */
    public interface IFrameRenderer
    {
        int renderFrame(int frameNum, Graphics graphics);
        Frame normalizeFrame(int frameNum);
    }

    /**
     * \interface IImportedFile
     * Interface to an imported file, such as an image or video
     * with multiple frames
     */
    public interface IImportedFile : IFrameRenderer
    {
        Size dimension { get; }
        int frameCount { get; }
        string srcFile { get; }
        object srcObject { get; }
    }

    /**
     * \interface IImportPlugin
     * Interface to an import plugin for loading and rendering media
     * and extracting frames
     */
    public interface IImportPlugin : IPlugin, IFrameRenderer
    {
        int frameCount { get; }
        object[] importedFiles { get; }
        string[] importedFilenames { get; }
        bool supportsMultipleFiles { get; }

        int loadFiles(string[] filenames, ProgressCallback progressCallback);
        void clearFiles();
        int getDimension(int frameNum, ref Size frameDimension);
    }
}
