﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.IO;
using System.Windows.Forms;
using System.Runtime.InteropServices;
using System.Reflection;

namespace ProcessingPluginLib
{
    public partial class ConfigForm : Form
    {
#if x64
        private const string CUDA_DLL = "libProcCuda64.dll";
#else
        private const string CUDA_DLL = "libProcCuda.dll";
#endif
        private bool x64Arch = false;

        [DllImport("kernel32.dll", CharSet = CharSet.Auto)]
        static extern IntPtr LoadLibrary(string lpFileName);

        [DllImport(CUDA_DLL)]
        static extern int testDevice(ref int maxThreadsPerBlock, int[] maxThreadsDim, int[] maxGridSize,
			   ref int major, ref int minor);

        public bool gpuEnable
        {
            get { return gpuCheckBox.Checked; }
            set { gpuCheckBox.Checked = value; }
        }

        public bool preserveUnfound
        {
            get { return preserveCheckBox.Checked; }
            set { preserveCheckBox.Checked = value; }
        }

        public int kernelWidth
        {
            get { return Convert.ToInt32(kernelWidthEdit.Value); }
            set { kernelWidthEdit.Value = value; }
        }

        public int searchFactor
        {
            get { return Convert.ToInt32(searchFacEdit.Value); }
            set { searchFacEdit.Value = value; }
        }

        public int minCoefficient
        {
            get { return Convert.ToInt32(minCoefficientEdit.Value); }
            set { minCoefficientEdit.Value = value; }
        }

        public int gpuMode
        {
            get { return gpuModeComboBox.SelectedIndex; }
            set
            {
                if (value < gpuModeComboBox.Items.Count)
                    gpuModeComboBox.SelectedIndex = value;
                else
                    gpuModeComboBox.SelectedIndex = 0;
            }
        }

        public ConfigForm(bool x64Arch)
        {
            InitializeComponent();
            this.x64Arch = x64Arch;

            if (!x64Arch)
            {
                Environment.CurrentDirectory = Path.GetDirectoryName(Assembly.GetAssembly(this.GetType()).Location);
                string dllPath = Path.GetFullPath(@CUDA_DLL);
                LoadLibrary(dllPath);
            }
        }

        private void kernelWidthEdit_ValueChanged(object sender, EventArgs e)
        {
            if (kernelWidthEdit.Value % 2 == 0)
            {
                if (kernelWidthEdit.Value == kernelWidthEdit.Maximum)
                    kernelWidthEdit.Value -= 1;
                else
                    kernelWidthEdit.Value += 1;
            }
        }

        private void gpuTestButton_Click(object sender, EventArgs e)
        {
            int maxThreadsPerBlock = 0;
            int[] maxThreadsDim = new int[3];
            int[] maxGridSize = new int[3];
            int major = 0;
            int minor = 0;

            if (!x64Arch && testDevice(ref maxThreadsPerBlock, maxThreadsDim, maxGridSize, ref major,
                ref minor) == 0 && major != 9999 && minor != 9999)
            {
                MessageBox.Show("Device information\n\nmaxThreadsPerBlock = " + maxThreadsPerBlock.ToString() +
                    "\nmaxThreadsDim.x = " + maxThreadsDim[0].ToString() +
                    "\nmaxThreadsDim.y = " + maxThreadsDim[1].ToString() +
                    "\nmaxThreadsDim.z = " + maxThreadsDim[2].ToString() +
                    "\nmaxGridSize.x = " + maxGridSize[0].ToString() +
                    "\nmaxGridSize.y = " + maxGridSize[1].ToString() +
                    "\nmaxGridSize.z = " + maxGridSize[2].ToString() +
                    "\nversion = " + major.ToString() + "." + minor.ToString());
                gpuCheckBox.Checked = true;
            }
            else
            {
                gpuCheckBox.Checked = false;
                if (x64Arch)
                    MessageBox.Show("This feature is not yet supported on 64bit systems.");
                else
                    MessageBox.Show("Couldn't get device information. No device found.");
            }
        }

        private void gpuModeComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            switch (gpuModeComboBox.SelectedIndex)
            {
                case 0:
                    gpuModeDescLabel.Text = "Displacement parallelization";
                    break;
                case 1:
                    gpuModeDescLabel.Text = "Vector parallelization (unstable)";
                    break;
            }
        }
    }
}
