﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace multidac
{
    /** a delegate method for canceling asynchronious processing **/
    public delegate void CancelProcessing(bool force);

    public partial class ProcessingForm : Form
    {
        private CancelProcessing cancelProcessing;
        private bool askBeforeCancelling;

        public ProcessingForm(CancelProcessing _cancelProcessing, bool _askBeforeCancelling)
        {
            InitializeComponent();
            cancelProcessing = _cancelProcessing;
            cancelButton.Enabled = _cancelProcessing != null;
            cancellingLabel.Hide();
            askBeforeCancelling = _askBeforeCancelling;
        }

        public void setTotalProgress(int progress, string msg)
        {
            if (progress < 0)
                progress = 0;
            if (progress > 100)
                progress = 100;

            totalProgressBar.Value = progress;
            totalProgressLabel.Text = "Action: " + msg;
            progressGroup.Refresh();
        }

        public void setRelativeProgress(int progress)
        {
            if (progress < 0)
                progress = 0;
            if (progress > 100)
                progress = 100;

            relativeProgressBar.Value = progress;
            relativeProgressBar.Refresh();
        }

        public void setTimeLabel(DateTime time)
        {
            if (time.CompareTo(DateTime.MinValue) != 0)
                timeLabel.Text = "Time remaining: " + time.ToLongTimeString();
            else
                timeLabel.Text = "Time remaining: n/a";
        }

        private void cancelButton_Click(object sender, EventArgs e)
        {
            if (cancelProcessing != null)
            {
                if (askBeforeCancelling && MessageBox.Show("Do you really want to cancel processing?", "Confirm",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
                    return;

                cancelProcessing(false);
                cancelButton.Enabled = false;
                cancellingLabel.Show();
            }
        }

        private void ProcessingForm_Shown(object sender, EventArgs e)
        {
            cancelButton.Focus();
        }

        private void ProcessingForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            cancelProcessing(true);
        }
    }
}
